vortex\_criterions package
======================================

.. automodule:: IMTreatment.vortex_criterions
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    IMTreatment.vortex_criterions.FTLE

.. toctree::

   IMTreatment.vortex_criterions.vortex_criterions

